@@ -4,18 +4,20 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveactiondiscard.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "editor/sieveeditorutil.h"
 #include <KLocalizedString>
 
 using namespace KSieveUi;
 SieveActionDiscard::SieveActionDiscard(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
-    : SieveAction(sieveGraphicalModeWidget, QStringLiteral("discard"), i18n("Discard"), parent)
+    : SieveAction(sieveGraphicalModeWidget, u"discard"_s, i18n("Discard"), parent)
 {
 }
 
 QString SieveActionDiscard::code(QWidget *) const
 {
-    return QStringLiteral("discard;");
+    return u"discard;"_s;
 }
 
 QString SieveActionDiscard::help() const
