@@ -5,6 +5,8 @@
 */
 
 #include "vacationmanager.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "ksieveui/vacation/multiimapvacationdialog.h"
 #include <KSieveCore/MultiImapVacationManager>
 #include <KSieveCore/VacationCreateScriptJob>
@@ -55,8 +57,8 @@ void VacationManager::slotUpdateVacationScriptStatus(bool active, const QString
                                                 i18n("There is still an active out-of-office reply configured.\n"
                                                      "Do you want to edit it?"),
                                                 i18nc("@title:window", "Out-of-office reply still active"),
-                                                KGuiItem(i18nc("@action:button", "Edit"), QStringLiteral("document-properties")),
-                                                KGuiItem(i18nc("@action:button", "Ignore"), QStringLiteral("dialog-cancel")))
+                                                KGuiItem(i18nc("@action:button", "Edit"), u"document-properties"_s),
+                                                KGuiItem(i18nc("@action:button", "Ignore"), u"dialog-cancel"_s))
                 == KMessageBox::ButtonCode::PrimaryAction) {
                 slotEditVacation(serverName);
             }
